//
//  MainMenuView.swift
//  DouShouQi_App
//
//  Created by Nathan Verdier on 26/05/2024.
//

import SwiftUI
import SpriteKit
import DouShouQiModel

struct GameView: View {
    var gameScene: GameScene = GameScene(size: CGSize(width: 700, height: 900))
    
    @StateObject var gameVM: PlayingGameVM
    
    @State private var showHome = false
    
    var body: some View {
        ZStack {
            VStack {
                TopGameBoard(gameVM: gameVM).frame(maxHeight: 200)
                SpriteView(scene: GameScene(size: CGSize(width: 700, height: 900), gameVM: gameVM))
            }
            .onAppear {
                playSound(named: "Fight")
                
                //MusicPlayer.shared.playBackgroundMusic(music: "GameMusic")
                
                DispatchQueue.main.asyncAfter(deadline: .now() + 0.7) {
                    MusicPlayer.shared.playBackgroundMusic(music: "GameMusic")
                }
            }
            .onDisappear {
                MusicPlayer.shared.stopBackgroundMusic()
            }
            
            if (gameVM.game.isOver) {
                HStack {
                    Spacer()
                    
                    VStack(alignment: .center) {
                        Text("Game Over")
                            .font(.title2)
                        Text("Winner: \(gameVM.winner)")
                    }
                    .background(Colors.WinnerBackground)
                    
                    Spacer()
                }
                .onAppear {
                    Timer.scheduledTimer(withTimeInterval: 10, repeats: false) { _ in
                        
                        // Il faut retourner au home
                    }
                }
            }
        }
        .onDisappear {
            MusicPlayer.shared.stopBackgroundMusic()
        }
        .navigationBarHidden(true)  // Hide the navigation bar
    }
}

/*struct GameView_Previews: PreviewProvider {
    static var previews: some View {
        GameView()
    }
}*/
